const HomeHelper = require('../helpers/HomeHelper')
const HomeValidator = require('../validators/HomeValidator')
const responseHelper = require('../../utils/responseHelper')
/**
 * This Home class get Home related APIs
 */

class Home {
    /**
     * Get Home list API
     * @param {string} name  search name
     * @returns success response with All Home details
     * @date 2022-08-23
     */

    async getChef(req, res) {
        try {
            let result = await HomeHelper.getChef(req.body);
            responseHelper.success(res, 'SUCCESS', req.headers.Section, result.data, '', result.total);
        } catch (error) {
            responseHelper.error(res, error, req.headers.Section);
        }
    }

    async getMeal(req, res) {
        try {
            await HomeValidator.getMealValidator(req.body);
            let result = await HomeHelper.getMeal(req.body);
            responseHelper.success(res, 'SUCCESS', req.headers.Section, result.data, '', result.total);
        } catch (error) {
            responseHelper.error(res, error, req.headers.Section);
        }
    }

    async getChefById(req, res) {
        try {
            await HomeValidator.getChefByIdValidator(req.body);
            let result = await HomeHelper.getChefById(req.body);
            responseHelper.success(res, 'SUCCESS', req.headers.Section, result.data, '', result.total);
        } catch (error) {
            responseHelper.error(res, error, req.headers.Section);
        }
    }

    async getRecipeByChefId(req, res) {
        try {
            await HomeValidator.getRecipeByChefIdValidator(req.body);
            let result = await HomeHelper.getRecipeByChefId(req.body);
            responseHelper.success(res, 'SUCCESS', req.headers.Section, result.data, '', result.total);
        } catch (error) {
            responseHelper.error(res, error, req.headers.Section);
        }
    }

    async getRelatedRecipe(req, res) {
        try {
            await HomeValidator.getRelatedRecipeValidator(req.body);
            let result = await HomeHelper.getRelatedRecipe(req.body);
            responseHelper.success(res, 'SUCCESS', req.headers.Section, result.data, '', result.total);
        } catch (error) {
            responseHelper.error(res, error, req.headers.Section);
        }
    }

    async getFavoritesRecipe(req, res) {
        try {
            await HomeValidator.getFavoritesRecipeValidator(req.body);
            let result = await HomeHelper.getFavoritesRecipeList(req.body);
            responseHelper.success(res, 'SUCCESS', req.headers.Section, result.data, '', result.total);
        } catch (error) {
            responseHelper.error(res, error, req.headers.Section);
        }
    }

    async getRecipeVideo(req, res) {
        try {
            let result = await HomeHelper.getRecipeVideo(req.body);
            responseHelper.success(res, 'SUCCESS', req.headers.Section, result.data, '', result.total);
        } catch (error) {
            responseHelper.error(res, error, req.headers.Section);
        }
    }

    async searchRecipe(req, res) {
        try {
            await HomeValidator.searchRecipeValidator(req.body);
            let result = await HomeHelper.searchRecipe(req.body);

            responseHelper.success(res, 'SUCCESS', req.headers.Section, result.data, '', result.total);
        } catch (error) {
            responseHelper.error(res, error, req.headers.Section);
        }
    }


    async bannerRecipe(req, res) {
        try {
            let result = await HomeHelper.bannerRecipe(req.body);
            responseHelper.success(res, 'SUCCESS', req.headers.Section, result.data, '', result.total);
        } catch (error) {
            responseHelper.error(res, error, req.headers.Section);
        }
    }

    async bestRecipe(req, res) {
        try {
            let result = await HomeHelper.bestRecipe(req.body);
            responseHelper.success(res, 'SUCCESS', req.headers.Section, result.data, '', result.total);
        } catch (error) {
            responseHelper.error(res, error, req.headers.Section);
        }
    }

    async trendingRecipe(req, res) {
        try {
            let result = await HomeHelper.trendingRecipe(req.body);
            responseHelper.success(res, 'SUCCESS', req.headers.Section, result.data, '', result.total);
        } catch (error) {
            responseHelper.error(res, error, req.headers.Section);
        }
    }

    async getComment(req, res) {
        try {
            await HomeValidator.getComment(req.body);
            let result = await HomeHelper.getComment(req.body);
            responseHelper.success(res, 'SUCCESS', req.headers.Section, result.data, '', result.total);
        } catch (error) {
            responseHelper.error(res, error, req.headers.Section);
        }
    }


}

module.exports = new Home();