const UserHelper = require('../helpers/UserHelper')
const UserValidator = require('../validators/UserValidator')
const responseHelper = require('../../utils/responseHelper')
const config = require('../../utils/config')
/**
 * This User class get User related APIs
 */

class User {

    /**
     * Get User list API
     * @param {string} name  search name
     * @returns success response with All User details
     * @date 2022-08-23
     */

    async register(req, res) {
        try {
            await UserValidator.registerValidator(req.body);
            let response = await UserHelper.register(req.body);
            responseHelper.success(res, 'SUCCESS', req.headers.User, response.data, '', response.total);
        } catch (error) {
            responseHelper.error(res, error, req.headers.user);
        }
    }

    async getUserProfile(req, res) {
        try {
            await UserValidator.getUserProfileValidator(req.body);
            let response = await UserHelper.getProfile(req.body);
            responseHelper.success(res, 'SUCCESS', req.headers.User, response.data, '', response.total);
        } catch (error) {
            responseHelper.error(res, error, req.headers.User);
        }
    }


    async updateProfile(req, res) {
        try {
            await UserValidator.updateProfileValidator(req.body);
            let response = await UserHelper.updateProfile(req.body);
            responseHelper.success(res, 'SUCCESS', req.headers.User, response.data, '', response.total);
        } catch (error) {
            responseHelper.error(res, error, req.headers.User);
        }
    }

    async becomeChef(req, res) {
        try {
            await UserValidator.becomeChefValidator(req.body);
            let response = await UserHelper.becomeChef(req.body);
            responseHelper.success(res, 'SUCCESS', req.headers.User, response.data, '', response.total);
        } catch (error) {
            responseHelper.error(res, error, req.headers.User);
        }
    }

    async login(req, res) {
        try {
            await UserValidator.loginValidator(req.body);
            let response = await UserHelper.login(req.body);
            console.log('response');
            console.log(response.data);

            responseHelper.success(res, response.message, req.headers.User, response.data, '', response.total);
        } catch (error) {
            responseHelper.error(res, error, req.headers.user);
        }
    }

    async imageUpload(req, res) {
        try {


            await UserValidator.imageUploadValidator(req.body);
            let response = await UserHelper.imageUpload(req);
            responseHelper.success(res, 'SUCCESS', req.headers.User, response.data, '', response.total);
        } catch (error) {

            responseHelper.error(res, error, req.headers.user);
        }
    }


    async mediaUpload(req, res) {
        try {
            let response = await UserHelper.mediaUpload(req);
            responseHelper.success(res, 'SUCCESS', req.headers.User, response.data, '', response.total);
        } catch (error) {

            responseHelper.error(res, error, req.headers.user);
        }
    }


}

module.exports = new User();